@@ -9,7 +9,7 @@ from vega.cli.templates import (
     render_fastapi_app,
     render_fastapi_health_route,
     render_fastapi_main,
-    render_fastapi_routes_init,
+    render_fastapi_routes_init_autodiscovery,
     render_fastapi_user_route,
     render_pydantic_models_init,
     render_pydantic_user_models,
@@ -37,7 +37,7 @@ def create_fastapi_scaffold(
         (web_dir / "__init__.py", render_web_package_init()),
         (web_dir / "app.py", render_fastapi_app(project_name)),
         (web_dir / "main.py", render_fastapi_main(project_name)),
-        (routes_dir / "__init__.py", render_fastapi_routes_init()),
+        (routes_dir / "__init__.py", render_fastapi_routes_init_autodiscovery()),
         (routes_dir / "health.py", render_fastapi_health_route()),
         (routes_dir / "users.py", render_fastapi_user_route()),
         (models_dir / "__init__.py", render_pydantic_models_init()),
