@@ -24,6 +24,10 @@ from .components import (
     render_alembic_env,
     render_alembic_script_mako,
     render_sqlalchemy_model,
+    render_cli_command,
+    render_cli_command_simple,
+    render_cli_commands_init,
+    render_fastapi_routes_init_autodiscovery,
 )
 from .loader import render_template
 
@@ -53,5 +57,9 @@ __all__ = [
     "render_alembic_env",
     "render_alembic_script_mako",
     "render_sqlalchemy_model",
+    "render_cli_command",
+    "render_cli_command_simple",
+    "render_cli_commands_init",
+    "render_fastapi_routes_init_autodiscovery",
     "render_template",
 ]
